#
# spec file for package gretl
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012, Efstathios Agrapidis (stathisagrapidis@gmail.com)
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libgretl-1_0-48
Name:           gretl
Version:        2024b
Release:        1.1
Summary:        GNU regression, econometrics and time-series library
License:        GPL-3.0-only
Group:          Productivity/Office/Finance
URL:            https://gretl.sourceforge.net/
Source0:        https://downloads.sourceforge.net/gretl/%{name}-%{version}.tar.xz
Source1:        https://downloads.sourceforge.net/gretl/gretl-guide.pdf
Source2:        https://downloads.sourceforge.net/gretl/gretl-ref.pdf
BuildRequires:  R-base-devel
BuildRequires:  fdupes
# Documented build requirements
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gnuplot
# Extra build requirements for openSUSE
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmp)
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(lapack)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgsf-1)
BuildRequires:  pkgconfig(libxml-2.0)
# Documented optional build requirements
BuildRequires:  pkgconfig(mpfr)
BuildRequires:  pkgconfig(readline)
# Documented runtime requirements
Requires:       gnuplot
%lang_package

%description
Gretl (GNU regression, econometrics and time-series library) comprises
libgretl, a shared library which provides various functions relating to
econometric estimation, a command-line client program and a gui client,
using GTK+.

%package -n %{libname}
Summary:        Shared library for %{name}
Group:          System/Libraries

%description -n %{libname}
This package contains the shared libraries for %{name}.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Other
Requires:       %{libname} = %{version}

%description devel
This package contains the development files for %{name}.

%package doc
Summary:        Documentation for gretl
BuildArch:      noarch

%description doc
This package provides the guide and command reference documentation (as PDF)
for gretl.

%prep
%autosetup
cp %{S:1} %{S:2} ./

%build
%configure \
  --disable-static \
  --disable-avx \
  --enable-build-editor \
  %{nil}
%make_build

%install
%make_install
%find_lang %{name}
find %{buildroot} -type f -name "*.la" -delete -print

%fdupes %{buildroot}%{_datadir}

%check
pushd tests
%make_build check
popd

%ldconfig_scriptlets -n %{libname}

%files
%doc ChangeLog CompatLog README
%{_bindir}/gretl*
%{_libdir}/%{name}-gtk3
%{_datadir}/%{name}/
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/*/mimetypes/*.png
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man1/*%{?_ext_man}

%files -n %{libname}
%license COPYING
%{_libdir}/libgretl*.so.*

%files lang -f %{name}.lang

%files devel
%license COPYING
%{_libdir}/pkgconfig/gretl.pc
%{_libdir}/libgretl*.so
%{_includedir}/%{name}/

%files doc
%doc gretl-*.pdf

%changelog
* Sat Jun 15 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2024b:
  * "gridplot" command: add a --title option
  * "clear" command: add an --all option
  * instrings() function: add optional boolean argument to get a
    simple boolean return value
  * typeof() function: functionality is extended to cover hansl
    expressions in general
  * exists() function: recommended usage is restricted to top-
    level identifiers, but backward compatibility is preserved for
    the present
  * new function binperms() for binary permutations
  * Testing for equality via "==" and "!=": extend this to cover
    arrays and bundles
  * help files: clarify the help for some commands and improve
    formatting
  * $sysinfo bundle: add "stack_size"
  * mrw (Mankiw-Romer-Weil) dataset: rename "inv" as "i_y"
  * Fix bug: crash on replacing a single character in a string
    variable, when the replacement UTF-8 character takes up more
    bytes than the original
  * Fix bug: potential crash when using the "smpl" command on a
    dataset that is already subject to random resampling
  * Fix bug: possible confusion in parsing lag specifications for
    list members, as in "list.vname(-1)"
  * Fix bug: possible interference of options passed in "plot"
    with those passed to "gnuplot"
  * Fix bug: crash in 32-bit gretl for Windows when trying to read
    gdtb data files created on a 64-bit system
  * Function packages: validate gfn files using an XML schema
    rather than a Document Type Definition
  * GUI, function packages: further extensions to the "ui-maker"
    functionality, plus minor fixes for the function-call dialog
  * GUI: support the --preserve-panel option in the dialog box for
    sub-sampling
  * GUI: support the Gamma distribution under /Tools/Distribution
    graphs
  * GUI: fix the "Packages" entry under Help
  * GUI: ensure that all fonts scale on zoom in/out in help
  * GUI: add more choices for plot scaling
  * GUI: improvements to the regls dialog
  * Internals: economize stack usage in case of nested function
    calls
  * regls addon: bug fixes and improved documentation
- Add guide and command reference PDFs as sources and install them
  as part of a new -doc package.
- Run checks as part of %%check section.
- Split out lang package.
- Drop changes made to .desktop file.
- Switch to "pkgconfig" based BuildRequires where possible.
- Bump shared library name to keep up with soversion bump.
- Minor specfile cleanups.
* Wed Sep 21 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- New upstream release 2022b
  See included Changelog file or
  http://gretl.sourceforge.net/ChangeLog.html
- Drop obsolete desktop-file-fixwarning.patch
* Fri Dec  4 2015 stathisagrapidis@gmail.com
- Fixed error: No sufficient Category definition.
* Thu Jun 19 2014 stathisagrapidis@gmail.com
- New upstream release 1.9.90
  * GUI reorganization: move the Function packages menu from
    /Files to /Tools
  * GUI enhancement: add News button under "/Help/About gretl"
    to display list of changes in the current version
  * Help menu: add item for the new "hansl primer" which covers
    the basics of gretl's scripting language
  * Introduce a new native binary datafile format, the gdtb file
    (zipped XML metadata plus binary values)
  * Add new functions: bread(), bwrite(), substr(), easterday()
  * "summary" command: add --weights option
  * "tabprint" command: add --csv option
  * fdjac function: provide choice of algorithm
  * Enable use of arrays in the SFMT random number generator
  * Enable use of value labels (if any) in factorized boxplots
  * Enable use of named lists in the GMM() and GMMlevel()
    parameter-groups for the "dpanel" and "arbond" commands
  * Print out alternative definition of R^2 in FE linear panel
    data models
  * Add choice of compression level when saving data in native
    gdt format
  * Stata dta import: handle (illegal!) non-ASCII characters in
    variable names
  * X-12-ARIMA interface: support the new X-13-ARIMA-SEATS as an
    alternative
  * Fix bug: incorrect plot header when the --radians option was
    given with the "pergm" command
  * Fix bug: the --test-down option to "coint" was not working
    as advertised
  * Fix bug (?): the final regression in "coint" (Engle-Granger
    test) could end up using a different sample range depending
    on whether or not the --skip-df option was given
  * Fix bug: incorrect handling of Poisson regression when the
    specification does not include an intercept term
  * Fix bug: bad handing of decimal comma in context of the --by
    option
  * Fix bug: incorrect treatment of big-endian SPSS "sav" files
    on data import
  * Fix bug: the auxiliary regression for White's test should
    contain a constant even if the model to be tested does not
  * Fix bug: wrong starting date being sent to x12a/x13as for
    monthly data starting in October
  * Fix bug: score calculation for random-effects probit was
    incorrect
  * Fix bug: incorrect estimates when the --robust option was
    used with the "wls" command
  * Fix bugs 181, 182
  * Internals: add support for multiple, independent PRNGs
  * configure script: add an option --disable-www which drops
    the libcurl dependency, conditional on not building the
* Tue Feb 18 2014 stathisagrapidis@gmail.com
- New upstream release 1.9.14
  * Use daily dates when plotting daily/weekly data and there
    are not too many observations
  * Line-numbering in the script editor: make this a preference
    which is remembered
  * mols() function: parallelize some of the work for builds
    with openmp enabled
  * GUI: provide a menu item for adding a panel unit index
  * GUI: "/File/Save data as" now switches the current dataset
    to the name of the saved one
  * Fix bug: the build of gnuplot included in the gretl-quartz
    package (for Mac) did not work properly in stand-alone mode
  * Fix bug: the importer for SAS "xport" files over-counted the
    number of observations, leading to out-of-memory failure on
    very big datasets
  * Fix bug: the --show-plot option to the "freq" command was not
    being respected
  * Fix bug: failure parsing value-labels for "int" arguments in
    building function packages
  * Fix bug: "foreach" loop failing when given a single term that
    is not a named list
  * Fix bug: panel Hausman test producing bad output under some
    conditions
- Updated gtksource build requirements.
* Tue Jul  9 2013 stathisagrapidis@gmail.com
- Fixed warning about file permissions of the upstream tarball.
- Added desktop-file-fixwarning.patch which fixes warning: invalid
  desktop file missing a semicolon as trailing character.
* Fri Jul  5 2013 stathisagrapidis@gmail.com
- New upstream version 1.9.12
* Mon Oct 22 2012 stathisagrapidis@gmail.com
- Used spaces instead of tabs.
- Removed %%clean section.
- Removed *.la files.
* Mon Oct 22 2012 stathisagrapidis@gmail.com
- Fixed warning: package built without RPM_OPT_FLAGS.
- Fixed warning: empty generic name in desktop file.
- Fixed warning: desktop file contains absolute path in icon.
* Sat Oct 20 2012 stathisagrapidis@gmail.com
- Made the BuildRequires one per line.
* Sat Aug 11 2012 stathisagrapidis@gmail.com
- Corrected the licence header of the spec to match the guidelines
  at http://en.opensuse.org/openSUSE:Specfile_guidelines .
* Mon Aug  6 2012 stathisagrapidis@gmail.com
- Cleaned the runtime requires from the explicit build requires.
- Minimised rpmlint warnings.
* Mon Aug  6 2012 stathisagrapidis@gmail.com
- Added runtime requires.
- Used suse_update_desktop_file macro for the desktop file.
- Using fdupes for duplicate files.
* Wed Aug  1 2012 stathisagrapidis@gmail.com
- Added optional build requires for building the documentation
- Categorized the BuildRequires section
* Wed Aug  1 2012 stathisagrapidis@gmail.com
- Added GNU R as a build dep to include R Lib into the build and
  fix the 64-bit-portability issue.
* Wed Aug  1 2012 stathisagrapidis@gmail.com
- Added gnome support to the build requires section.
- Added the extra files to the filelist section.
* Thu Jul 26 2012 stathisagrapidis@gmail.com
- Used macros everywhere on the filelist section.
- Corrected the licence to be spdx compliant.
* Wed Jul 25 2012 stathisagrapidis@gmail.com
- First successful build.
- Used macros on the file section.
- Splitted some files to devel package.
* Wed Jul 25 2012 stathisagrapidis@gmail.com
  Added Requires and Provides. Added the filelist.-
* Wed Jul 25 2012 stathisagrapidis@gmail.com
  Corrected the date on the header and the GPL licence version.-
